@@ -6,7 +6,7 @@ use Path::Class::File 0.34 qw{}; #move_to capability
 use Archive::Extract qw{};
 use base qw{Path::Class::File};
 
-our $VERSION = '0.14';
+our $VERSION = '0.18';
 
 =head1 NAME
 
@@ -40,20 +40,25 @@ Note: These files are temporary and will be cleaned up when the file object vari
 
 sub extract {
   my $self   = shift;
-  my $ae     = Archive::Extract->new(archive=>"$self");
-  my $ae_dir = File::Tempdir->new;
-  $ae->extract(to => $ae_dir->name) or die $ae->error; #extracts all files to a temp dir
+  my $ae     = Archive::Extract->new(archive=>"$self") or die(qq{Error: Cannot create Archive::Extract object with archive "$self". Verfiy extension.});
+  my $ae_dir = File::Tempdir->new                      or die(qq{Error: Cannot create File::Tempdir object});
+  $ae->extract(to => $ae_dir->name)                    or die(qq{Error: }. $ae->error); #extracts all files to a temp dir
   my @files  = ();
   my $filenames = $ae->files; #array reference in scalar context
   #loop through each file, bless and move to individual temp folders
   foreach my $filename (@$filenames) {
-    my $tmpdir  = File::Tempdir->new;                     #separate tmp directory for each file for fine grained cleanup
-    die(sprintf(qq{Error: Dir "%s" is not a directory}, $tmpdir->name)) unless -d $tmpdir->name;
     my $file    = $self->new($ae_dir->name => $filename); #isa Path::Class::File object
     die(sprintf(qq{Error: File "%s" is not readable.}, $file)) unless -r $file;
-    $file->move_to(Path::Class::File->new($tmpdir->name, $filename)) or die("Error: Failed to move file to temp directory");
+
+    next unless -f $file;                                 #only process files and not folders
+
+    my $tmpdir  = File::Tempdir->new;                     #separate tmp directory for each file for fine grained cleanup
+    die(sprintf(qq{Error: Dir "%s" is not a directory}, $tmpdir->name)) unless -d $tmpdir->name;
+
+    $file->move_to(Path::Class::File->new($tmpdir->name, $file->basename)) or die("Error: Failed to move file to temp directory");
     $file->{"__tmpdir"} = $tmpdir;                        #needed for scope clean up of File::Tempdir object
     die(sprintf(qq{Error: File "%s" is not readable.}, $file)) unless -r $file;
+
     push @files, $file;
   }
   return wantarray ? @files : \@files;
@@ -71,25 +76,36 @@ Support other archive formats besides zip
 
 =head1 BUGS
 
-Send email to author and log on RT.
-
-=head1 SUPPORT
-
-DavisNetworks.com supports all Perl applications including this package.
+Use GitHub to fork repository and submit pull requests.
 
 =head1 AUTHOR
 
   Michael R. Davis
   CPAN ID: MRDVT
-  Satellite Tracking of People, LLC
-  mdavis@stopllc.com
-  http://www.stopllc.com/
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+MIT License
 
-The full text of the license can be found in the LICENSE file included with this module.
+Copyright (c) 2021 Michael R. Davis
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 
 =head1 SEE ALSO
 
